summaryrefslogtreecommitdiffstats
path: root/src/modules/objects/class_groupbox.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:33:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:33:07 -0600
commit805c2821ceaddada48b346c6d11bd0dc1351a539 (patch)
treef4f34d4fae6b86d1b1058f396da4729906edbadb /src/modules/objects/class_groupbox.cpp
parent918c3ff07736f0c343cb190d3f0df99e4cb8dab8 (diff)
downloadkvirc-805c2821ceaddada48b346c6d11bd0dc1351a539.tar.gz
kvirc-805c2821ceaddada48b346c6d11bd0dc1351a539.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'src/modules/objects/class_groupbox.cpp')
-rw-r--r--src/modules/objects/class_groupbox.cpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/src/modules/objects/class_groupbox.cpp b/src/modules/objects/class_groupbox.cpp
index 07f73bea..7c011403 100644
--- a/src/modules/objects/class_groupbox.cpp
+++ b/src/modules/objects/class_groupbox.cpp
@@ -29,7 +29,7 @@
#include "kvi_locale.h"
#include "kvi_iconmanager.h"
// Tables used in $tqsetAlignment , $tqalignment and in $setOrientation & $orientation
const char * const align_tbl[] = {
"Left",
@@ -60,8 +60,8 @@ const int align_cod[] = {
@description:
This widget can be used to display a groupbox.
It will be usually a parent for other child controls.
- You can either use a child tqlayout to manage the tqchildren geometries
- or use $setColumnLayout to manage the tqlayout automatically.
+ You can either use a child layout to manage the children geometries
+ or use $setColumnLayout to manage the layout automatically.
@functions:
!fn: $setTitle(<text:String>)
Sets the group box title to <text>.
@@ -89,14 +89,14 @@ const int align_cod[] = {
Returns the number of columns or rows in the groupbox.
!fn: $addSpace()
Adds an empty cell at the next free position.
- !fn: <string> $tqalignment()
- Returns the tqalignment of the group box title.
- !fn: $tqsetAlignment(<tqalignment:string>)
- Set the tqalignment of the groupbox; Valid values are Left,Right,HCenter.
+ !fn: <string> $alignment()
+ Returns the alignment of the group box title.
+ !fn: $setAlignment(<alignment:string>)
+ Set the alignment of the groupbox; Valid values are Left,Right,HCenter.
!fn: $setOrientation<orientation:string>
Sets the group box's orientation. Valid values are:Qt::Horizontal,Qt::Vertical.
!fn: $setColumnLayout(<columns:integer>,<orientation:string>)
- Enables the automatic tqlayout management. The tqchildren are arranged in n columns with the specified orientation.[br]
+ Enables the automatic layout management. The children are arranged in n columns with the specified orientation.[br]
Valid values for <orientation> are:Qt::Horizontal,Qt::Vertical.
@examples:
[example]
@@ -108,7 +108,7 @@ const int align_cod[] = {
#then the groupbox [br]
%gb=$new(groupbox,%widget)[br]
%gb->$setTitle(Login)[br]
- %gb->$tqsetAlignment("Left")[br]
+ %gb->$setAlignment("Left")[br]
[br]
#now we create the labels and lineedits.[br]
%labeluser=$new(label,%gb)[br]
@@ -120,16 +120,16 @@ const int align_cod[] = {
%inputpass->$setechomode("password")[br]
[br]
#now lets' layouting the groupbox's element's.[br]
- %layoutgb=$new(tqlayout,%gb)[br]
+ %layoutgb=$new(layout,%gb)[br]
%layoutgb->$setmargin(20)[br]
%layoutgb->$addwidget(%labeluser,0,0)[br]
%layoutgb->$addwidget(%labelpass,1,0)[br]
%layoutgb->$addwidget(%inputuser,0,1)[br]
%layoutgb->$addwidget(%inputpass,1,1)[br]
[br]
- # now we create a fake widget and managing the two buttons tqlayout.[br]
+ # now we create a fake widget and managing the two buttons layout.[br]
%fakewidget=$new(widget,%widget)[br]
- %layoutbtn=$new(tqlayout,%fakewidget)[br]
+ %layoutbtn=$new(layout,%fakewidget)[br]
%btnok=$new(button,%fakewidget)[br]
%btnok->$settext("OK")[br]
%btncancel=$new(button,%fakewidget)[br]
@@ -137,13 +137,13 @@ const int align_cod[] = {
%layoutbtn->$addwidget(%btnok,0,0)[br]
%layoutbtn->$addwidget(%btncancel,0,1)[br]
[br]
#And finally we create a main tqlayout with the groupbox (and its "tqchildren")[br]
#and fakewiget (with its buttons tqchildren).
%maintqlayout=$new(tqlayout,%widget)[br]
%maintqlayout->$setspacing(10)[br]
%maintqlayout->$setmargin(10)[br]
%maintqlayout->$addwidget(%gb,0,0)[br]
%maintqlayout->$addwidget(%fakewidget,1,0)[br]
[br]
#Let's show our nice login request =D ! [br]
%widget->$show()[br]
@@ -165,8 +165,8 @@ KVSO_BEGIN_REGISTERCLASS(KviKvsObject_groupbox,"groupbox","widget")
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setColumns", functionSetColumns)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"columns", functionColumns)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"addSpace", functionAddSpace)
- KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"tqalignment", functionAlignment)
- KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"tqsetAlignment", functionSetAlignment)
+ KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"alignment", functionAlignment)
+ KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setAlignment", functionSetAlignment)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setOrientation", functionSetOrientation)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"isChecked", functionIsChecked)
KVSO_REGISTER_HANDLER(KviKvsObject_groupbox,"setChecked", functionSetChecked)
@@ -310,23 +310,23 @@ bool KviKvsObject_groupbox::functionSetAlignment(KviKvsObjectFunctionCall *c)
{
TQString szAlign;
KVSO_PARAMETERS_BEGIN(c)
- KVSO_PARAMETER("tqalignment",KVS_PT_STRING,0,szAlign)
+ KVSO_PARAMETER("alignment",KVS_PT_STRING,0,szAlign)
KVSO_PARAMETERS_END(c)
if (!widget()) return true;
for(unsigned int i = 0; i < align_num; i++)
{
if(KviTQString::equalCI(szAlign, align_tbl[i]))
{
- ((KviTalGroupBox *)widget())->tqsetAlignment(align_cod[i]);
+ ((KviTalGroupBox *)widget())->setAlignment(align_cod[i]);
return true;
}
}
- c->warning(__tr2qs("Unknown tqalignment"));
+ c->warning(__tr2qs("Unknown alignment"));
return true;
}
bool KviKvsObject_groupbox::functionAlignment(KviKvsObjectFunctionCall *c)
{
- int mode = ((KviTalGroupBox *)widget())->tqalignment();
+ int mode = ((KviTalGroupBox *)widget())->alignment();
TQString szAlignment="";
for(unsigned int i = 0; i < align_num; i++)
{
@@ -29,7 +29,7 @@
#include "kvi_locale.h"
#include "kvi_iconmanager.h"
-// Tables used in $tqsetAlignment , $tqalignment and in $setOrientation & $orientation
+// Tables used in $setAlignment , $alignment and in $setOrientation & $orientation
const char * const align_tbl[] = {
"Left",
@@ -137,13 +137,13 @@ const int align_cod[] = {
%layoutbtn->$addwidget(%btncancel,0,1)[br]
[br]
- #And finally we create a main tqlayout with the groupbox (and its "tqchildren")[br]
- #and fakewiget (with its buttons tqchildren).
- %maintqlayout=$new(tqlayout,%widget)[br]
- %maintqlayout->$setspacing(10)[br]
- %maintqlayout->$setmargin(10)[br]
- %maintqlayout->$addwidget(%gb,0,0)[br]
- %maintqlayout->$addwidget(%fakewidget,1,0)[br]
+ #And finally we create a main layout with the groupbox (and its "children")[br]
+ #and fakewiget (with its buttons children).
+ %mainlayout=$new(layout,%widget)[br]
+ %mainlayout->$setspacing(10)[br]
+ %mainlayout->$setmargin(10)[br]
+ %mainlayout->$addwidget(%gb,0,0)[br]
+ %mainlayout->$addwidget(%fakewidget,1,0)[br]
[br]
#Let's show our nice login request =D ! [br]